package uk.co.petertribble.picl;

import java.util.*;

/**
 * Java interface to Solaris PICL data.
 * Simply specifies an enumeration and lookup mechanism.
 */
public class PiclObject {

    private String piclclass;
    private String piclname;
    private Map <String, String> picldata;
    private List <PiclObject> piclnodes;

    static {
	System.loadLibrary("picl_jni");
    }

    public PiclObject() {
	picldata = new HashMap <String, String> ();
	piclnodes = new ArrayList <PiclObject> ();
    }

    /**
     * enumerate the available data, starting from the root piclObject
     */
    public native int enumerate();

    // called from jni
    public void setNames(String piclclass, String piclname) {
	this.piclclass = piclclass;
	this.piclname = piclname;
    }

    // called from jni
    public void addChild(PiclObject piclChild) {
	piclnodes.add(piclChild);
    }

    // called from jni
    public void addData(String dname, String ddata) {
	picldata.put(dname, ddata);
    }

    // called from jni
    public void addBlankData(String dname) {
	addData(dname, "");
    }

    public String getPiclClass() {
	return piclclass;
    }

    public String getPiclName() {
	return piclname;
    }

    public Map <String, String> getPiclData() {
	return picldata;
    }

    public List <PiclObject> getChildren() {
	return piclnodes;
    }

    public String childList() {
	StringBuffer sb = new StringBuffer();
	sb.append(piclnodes.toString());
	return sb.toString();
    }

    public String toString() {
	StringBuffer sb = new StringBuffer();
	sb.append(piclclass).append(":").append(piclname);
	return sb.toString();
    }
}
